---
title: <span class="badge object-type-scalar"></span> Pascals
---
# <span class="badge object-type-scalar"></span> Pascals

Pressure: Pascals

## Definition

```python
# Pressure: Pascals
Pascals: typing.Literal["pressurepa"] = "pressurepa"
```
